@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2015 Richard Hughes <richard@hughsie.com`
+ * Copyright (C) 2014-2016 Richard Hughes <richard@hughsie.com`
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -80,6 +80,15 @@ G_BEGIN_DECLS
  * @AS_TAG_LOCATION:			`location`
  * @AS_TAG_CHECKSUM:			`checksum`
  * @AS_TAG_SIZE:			`size`
+ * @AS_TAG_TRANSLATION:			`translation`
+ * @AS_TAG_CONTENT_RATING:		`content_rating`
+ * @AS_TAG_CONTENT_ATTRIBUTE:		`content_attribute`
+ * @AS_TAG_VERSION:			`version`
+ * @AS_TAG_REVIEWS:			`reviews`
+ * @AS_TAG_REVIEW:			`review`
+ * @AS_TAG_REVIEWER_NAME:		`reviewer_name`
+ * @AS_TAG_REVIEWER_ID:			`reviewer_id`
+ * @AS_TAG_SUGGESTS:			`suggests`
  *
  * The tag type.
  **/
@@ -133,6 +142,14 @@ typedef enum {
 	AS_TAG_CHECKSUM,		/* Since: 0.3.5 */
 	AS_TAG_SIZE,			/* Since: 0.5.2 */
 	AS_TAG_TRANSLATION,		/* Since: 0.5.8 */
+	AS_TAG_CONTENT_RATING,		/* Since: 0.5.12 */
+	AS_TAG_CONTENT_ATTRIBUTE,	/* Since: 0.5.12 */
+	AS_TAG_VERSION,			/* Since: 0.6.1 */
+	AS_TAG_REVIEWS,			/* Since: 0.6.1 */
+	AS_TAG_REVIEW,			/* Since: 0.6.1 */
+	AS_TAG_REVIEWER_NAME,		/* Since: 0.6.1 */
+	AS_TAG_REVIEWER_ID,		/* Since: 0.6.1 */
+	AS_TAG_SUGGESTS,		/* Since: 0.6.1 */
 	/*< private >*/
 	AS_TAG_LAST
 } AsTag;
